@@ -4,7 +4,8 @@ import json
 import logging
 import os
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Any, Callable
+from collections.abc import Callable
+from typing import TYPE_CHECKING, Any
 from urllib.error import HTTPError
 from urllib.request import Request, urlopen
 
@@ -375,7 +376,7 @@ class DuplicateKeyReportingMixin(StacIO):
 
     @staticmethod
     def _report_duplicate_object_names(
-        object_pairs: list[tuple[str, Any]]
+        object_pairs: list[tuple[str, Any]],
     ) -> dict[str, Any]:
         result: dict[str, Any] = {}
         for key, value in object_pairs:
@@ -414,17 +415,16 @@ if HAS_URLLIB3:
 
         """
 
-        retry: Retry
-        """The :py:class:`urllib3.util.retry.Retry` to use with all reading network
-        requests."""
-
         def __init__(
             self,
             headers: dict[str, str] | None = None,
             retry: Retry | None = None,
         ):
             super().__init__(headers)
+
             self.retry = retry or Retry()
+            """The :py:class:`urllib3.util.retry.Retry` to use with all reading network
+            requests."""
 
         def read_text_from_href(self, href: str) -> str:
             """Reads file as a UTF-8 string, with retry support.
@@ -438,7 +438,9 @@ if HAS_URLLIB3:
                 http = PoolManager()
                 try:
                     response = http.request(
-                        "GET", href, retries=self.retry  # type: ignore
+                        "GET",
+                        href,
+                        retries=self.retry,  # type: ignore
                     )
                     return cast(str, response.data.decode("utf-8"))
                 except HTTPError as e:
