@@ -1,7 +1,6 @@
 import os
-from typing import Optional
 
-__version__ = "1.10.1"
+__version__ = "1.11.0"
 """Library version"""
 
 
@@ -9,8 +8,11 @@ class STACVersion:
     DEFAULT_STAC_VERSION = "1.0.0"
     """Latest STAC version supported by PySTAC"""
 
+    DEFAULT_STAC_API_VERSION = "1.0.0"
+    """Latest STAC API version supported by PySTAC"""
+
     # Version that holds a user-set STAC version to use.
-    _override_version: Optional[str] = None
+    _override_version: str | None = None
 
     OVERRIDE_VERSION_ENV_VAR = "PYSTAC_STAC_VERSION_OVERRIDE"
 
@@ -26,7 +28,7 @@ class STACVersion:
         return cls.DEFAULT_STAC_VERSION
 
     @classmethod
-    def set_stac_version(cls, stac_version: Optional[str]) -> None:
+    def set_stac_version(cls, stac_version: str | None) -> None:
         cls._override_version = stac_version
 
 
@@ -45,7 +47,7 @@ def get_stac_version() -> str:
     return STACVersion.get_stac_version()
 
 
-def set_stac_version(stac_version: Optional[str]) -> None:
+def set_stac_version(stac_version: str | None) -> None:
     """Sets the STAC version that PySTAC should use.
 
     This is the version that will be set as the "stac_version" property
